API Reference
=============

Group Lasso regularised estimators
----------------------------------

.. autoclass:: group_lasso.GroupLasso
    :inherited-members:

.. autoclass:: group_lasso.LogisticGroupLasso
    :inherited-members:


Utilities for group lasso
--------------------------

.. automodule:: group_lasso.utils
    :members: extract_ohe_groups
